@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2015-11-17'; # DATE
-our $VERSION = '1.38'; # VERSION
+our $DATE = '2015-11-21'; # DATE
+our $VERSION = '1.39'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -57,7 +57,7 @@ has validate_args => (
     default => 1,
 );
 
-my $formats = [qw/text text-simple text-pretty json json-pretty/];
+my $formats = [qw/text text-simple text-pretty json json-pretty csv/];
 
 sub BUILD {
     my ($self, $args) = @_;
@@ -449,7 +449,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 1.38 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-11-17.
+This document describes version 1.39 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-11-21.
 
 =head1 SYNOPSIS
 
